//
//  ViewController.swift
//  ex_tableView_cell
//
//  Created by yoshiyuki oshige on 2014/09/29.
//  Copyright (c) 2014年 yoshiyuki oshige. All rights reserved.
//

import UIKit

// セルデータの型
struct CellData {
    var image:Animal
    var text:Sentence
    enum Animal:String {
        case kaeru = "frog.png"
        case azarashi = "azarashi.png"
    }
    enum Sentence:String {
        case sentence1 = "我輩は蛙である。"
        case sentence2 = "我輩は蛙である。名前はまだない。主人は教師である。"
        case sentence3 = "親譲りの無鉄砲でアザラシの時から損ばかりしてる。"
    }
}

class ViewController: UIViewController, UITableViewDelegate, UITableViewDataSource  {
    // セルデータの配列
    var tableData:[CellData] = []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // セルに表示するデータを用意する
        let data1 = CellData(image:.kaeru, text:.sentence1)
        let data2 = CellData(image:.kaeru, text:.sentence2)
        let data3 = CellData(image:.azarashi, text:.sentence3)
        tableData = [data1, data2, data2, data3, data2, data3, data3, data1]
        // テーブルビューを作る
        let tableView = UITableView(frame: self.view.frame, style: UITableViewStyle.Grouped)
        
        self.view.addSubview(tableView)
        // テーブルビューのデリゲートとデータソースになる
        tableView.delegate = self
        tableView.dataSource = self
        // xibをテーブルビューのセルとして使う
        let xib = UINib(nibName: "TableViewCell", bundle: nil)
        tableView.registerNib(xib, forCellReuseIdentifier: "Cell")
    }
    
    // 行数を返す（UITableViewDataSource）
    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // 行数はセルデータの個数
        return tableData.count
    }
    
    // セルにデータを設定する（UITableViewDataSource）
    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        // セルを取り出す
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell") as! TableViewCell
        // セルに表示するデータを取り出す
        let cellData = tableData[indexPath.row]
        // イメージビューに画像を設定する
        let fname = cellData.image.rawValue
        cell.cellImage.image = UIImage(named:fname)
        // ラベルにテキストを設定する
        let text = cellData.text.rawValue
        cell.cellLabel.text = text
        
        // 設定済みのセルを戻す
        return cell
    }
    
    // セクション数
    func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }
    
    // セクションのタイトル（UITableViewDataSource）
    func tableView(tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return "リスト"
    }
    
    // セルの高さを返す（UITableViewDelegate）
    func tableView(tableView: UITableView, heightForRowAtIndexPath indexPath: NSIndexPath) -> CGFloat{
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell") as! TableViewCell
        // セルの高さ
        return cell.bounds.height
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}
